@@ -5,7 +5,7 @@ sys.path.append('../')
 from ctypes import *
 from commFunction import emxArray_real_T,get_data_of_ctypes_
 import ctypes
-
+import platform
 #  * -------------------------------------------------------------------------
 #  * Arguments    : const emxArray_real_T *sig_mic
 #  *                const emxArray_real_T *sig_far
@@ -49,7 +49,13 @@ def cal_erle(micFile = None,testFile =None, refFile =None,targetType=0):
 
     # if refsamplerate != testsamplerate :
     #     raise TypeError('Different format of ref and test files!')
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/ERLE_estimation.dll')
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/ERLE_estimation.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/ERLE_estimation.dylib')
+
     mydll.ERLE_estimation.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double,c_double,c_double,POINTER(c_double),POINTER(c_double),POINTER(c_double),POINTER(c_double)]
     data_format = c_double*11
     gain_table = data_format()
@@ -64,6 +70,8 @@ def cal_erle(micFile = None,testFile =None, refFile =None,targetType=0):
 
 
 if __name__ == '__main__':
+    import platform
+    print(platform.platform().split('-')[0])
     micfile = r'C:\Users\vcloud_avl\Documents\我的POPO\0\stdRefFile.wav'
     test = r'C:\Users\vcloud_avl\Documents\我的POPO\0\mixDstFile.wav'
     ref = R'C:\Users\vcloud_avl\Documents\我的POPO\0\ref_cn.wav'
