@@ -5,7 +5,7 @@ sys.path.append('../')
 from ctypes import *
 from commFunction import emxArray_real_T,get_data_of_ctypes_
 import ctypes
-
+import platform
 
 # void SNR_transient(const emxArray_real_T *ref, const emxArray_real_T *ref_noise,
 #                    const emxArray_real_T *sig, double fs, double *SNR, double
@@ -23,7 +23,14 @@ def cal_attack_release(refFile=None, testFile=None):
 
     if refsamplerate != testsamplerate :
         raise TypeError('Different format of ref and test files!')
-    mydll = ctypes.windll.LoadLibrary(sys.prefix + '/attackrelease.dll')
+
+    mydll = None
+    cur_paltform = platform.platform().split('-')[0]
+    if cur_paltform == 'Windows':
+        mydll = ctypes.windll.LoadLibrary(sys.prefix + '/attackrelease.dll')
+    if cur_paltform == 'macOS':
+        mydll = CDLL(sys.prefix + '/attackrelease.dylib')
+
     mydll.attackrelease_estimation.argtypes = [POINTER(emxArray_real_T),POINTER(emxArray_real_T),c_double,c_double, POINTER(c_double),POINTER(c_double),POINTER(c_double)]
     time_attack,time_release,err = c_double(0.0),c_double(0.0),c_double(0.0)
     mydll.attackrelease_estimation(byref(refstruct),byref(teststruct),c_double(refsamplerate),c_double(refsamplerate),byref(time_attack),byref(time_release),byref(err))
